@@ -34,15 +34,15 @@ class KineticAnalyzer:
   """
   Load Dataset of SBML files.
 
-  Kinetic law type (K type) including ten types "ZERO" (Zeroth order), "UNDR" 
+  Kinetics type (K type) including ten types "ZERO" (Zeroth order), "UNDR" 
   (Uni-directional mass action), "UNMO" (Uni-term with moderator), "BIDR" 
   (Bi-directional mass action), "BIMO" (Bi-terms with moderator), "MM" 
   (Michaelis-Menten kinetics without explicit enzyme), "MMCAT" 
   (Michaelis-Menten kinetics with explicit enzyme), "HILL" (Hill equations), 
-  "FR" (Kinetics in the format of fraction other than MM, MMCAT or HILL) and "NA" 
+  "FR" (Kinetic law in the format of fraction other than MM, MMCAT or HILL) and "NA" 
   (not classified kinetics). 
 
-  Mass transfer type (M type) is quantitatively represented by the number of reactants 
+  Reaction type (R type) is quantitatively represented by the number of reactants 
   (r = 0, 1, 2, 3 (representing>2)) and products (p= 0, 1, 2, 3 (representing>2)).
 
   Args: 
@@ -86,10 +86,10 @@ class KineticAnalyzer:
 
   def getKTypeDistribution(self):
     """
-    Get the kinetic law type distribution.
+    Get the kinetics type distribution.
 
     Returns:
-        df_gen_stat_final: dataFrame-kinetic law type distribution. 
+        df_gen_stat_final: dataFrame-kinetics type distribution. 
         The column names are: "Classifications", "Percentage", "Percentage standard error", 
         "Percentage per model", "Percentage per model standard error".
         
@@ -109,20 +109,20 @@ class KineticAnalyzer:
     return df_gen_stat_final
 
 
-  def getKTypeDistributionPerMType(self, M_type):
+  def getKTypeDistributionPerRType(self, R_type):
     """
-    Get the kinetic law type distribution for the certein mass transfer type.
+    Get the kinetics type distribution for the certein reaction type.
 
     Args: 
-        M_type: an object with attributes rct_num and prd_num representing
-            the number of reactants and products.
+        R_type: an object with attributes rct_num and prd_num representing 
+        the number of reactants and products.
 
         rct_num: int-0, 1, 2, 3 (representing > 2).
         
         prd_num: int-0, 1, 2, 3 (representing > 2).
         
     Returns:
-        df_gen_stat_PR_final: dataFrame-the kinetic law distribution for a certain mass trasfer.
+        df_gen_stat_PR_final: dataFrame-the kinetics distribution for a reaction type.
         
         The column names are: "Classifications", "Percentage", "Percentage standard error", 
         "Percentage per model", "Percentage per model standard error".
@@ -130,8 +130,8 @@ class KineticAnalyzer:
         The column of "Classifications" covers the ten kinetic law types.
         
     """  
-    rct_num = M_type.rct_num
-    prd_num = M_type.prd_num
+    rct_num = R_type.rct_num
+    prd_num = R_type.prd_num
 
     (_, df_gen_stat, _, df_gen_stat_PR, _, _, _) = self.tuple
 
@@ -158,12 +158,12 @@ class KineticAnalyzer:
     else:
       raise Exception("Not a valid reactant or product number.")
 
-  def getMTypeDistribution(self):
+  def getRTypeDistribution(self):
     """
-    Get the distribution of reaction involved for each type of mass transfer.
+    Get the distribution of reaction involved for each reaction type.
 
     Returns:
-        df_table_PR_final: dataFrame-Mass transfer type distribution. 
+        df_table_PR_final: dataFrame-Reaction type distribution. 
         
         The column names represent number of reactants: "R = 0", "R = 1", "R = 2", "R > 2".
 
@@ -180,12 +180,12 @@ class KineticAnalyzer:
     except Exception as e:
       raise Exception(e)
 
-  def getMTypeDistributionPerModel(self):
+  def getRTypeDistributionPerModel(self):
     """
-    Get the distribution of reaction involved for each type of mass transfer per model.
+    Get the distribution of reaction involved for each reaction type per model.
 
     Returns:
-        df_table_PR_per_model final: dataFrame-Mass transfer type distribution. 
+        df_table_PR_per_model final: dataFrame-Reaction type distribution. 
         
         The column names represent number of reactants: "R = 0", "R = 1", "R = 2", "R > 2".
 
@@ -205,21 +205,21 @@ class KineticAnalyzer:
   ##Query Elements
   def getTopKType(self):
     """
-    Get the most frequent kinetic law type. 
+    Get the most frequent kinetics type. 
 
     Returns:
         kinetic_type_list: list of K_type. Sometimes there could be more than one
-        top kinetic law type to make the length of kinetic_type_list larger than one. 
+        top kinetics type to make the length of kinetic_type_list larger than one. 
         
-        K_type: an object with attributes K_type_str representing
-            the type of kinetic law.
+        K_type: an object with an attribute K_type_str representing 
+        the type of kinetics.
 
         K_type_str: str-"ZERO" (Zeroth order), "UNDR" 
-        (Uni-directional mass action), "UNMO" (Uni-term with moderator), "BIDR" 
-        (Bi-directional mass action), "BIMO" (Bi-terms with moderator), "MM" 
-        (Michaelis-Menten kinetics without explicit enzyme), "MMCAT" 
-        (Michaelis-Menten kinetics with explicit enzyme), "HILL" (Hill equations), 
-        "FR" (Kinetics in the format of fraction other than MM, MMCAT or HILL) and "NA" 
+        (Uni-directional mass action), "UNMO" (Uni-term with the moderator), "BIDR" 
+        (Bi-directional mass action), "BIMO" (Bi-terms with the moderator), "MM" 
+        (Michaelis-Menten kinetics without an explicit enzyme), "MMCAT" 
+        (Michaelis-Menten kinetics with an explicit enzyme), "HILL" (Hill equations), 
+        "FR" (Kinetic law in the format of fraction other than MM, MMCAT or HILL) and "NA" 
         (not classified kinetics). 
  
     """  
@@ -235,22 +235,22 @@ class KineticAnalyzer:
   
   def getKTypeProb(self, K_type):
     """
-    Get the probability value of the certain kinetic law type.
+    Get the probability value of the certain kinetics type.
 
     Args:
-        K_type: an object with attributes K_type_str representing
-            the type of kinetic law.
+        K_type: an object with an attribute K_type_str representing 
+        the type of kinetic law.
 
         K_type_str: str-"ZERO" (Zeroth order), "UNDR" 
-        (Uni-directional mass action), "UNMO" (Uni-term with moderator), "BIDR" 
-        (Bi-directional mass action), "BIMO" (Bi-terms with moderator), "MM" 
-        (Michaelis-Menten kinetics without explicit enzyme), "MMCAT" 
-        (Michaelis-Menten kinetics with explicit enzyme), "HILL" (Hill equations), 
-        "FR" (Kinetics in the format of fraction other than MM, MMCAT or HILL) and "NA" 
+        (Uni-directional mass action), "UNMO" (Uni-term with the moderator), "BIDR" 
+        (Bi-directional mass action), "BIMO" (Bi-terms with the moderator), "MM" 
+        (Michaelis-Menten kinetics without an explicit enzyme), "MMCAT" 
+        (Michaelis-Menten kinetics with an explicit enzyme), "HILL" (Hill equations), 
+        "FR" (Kinetic law in the format of fraction other than MM, MMCAT or HILL) and "NA" 
         (not classified kinetics). 
 
     Returns:
-        kinetics_value: float-the probability of the certain kinetic law type.
+        kinetics_value: float-the probability of the certain kinetics type.
     """  
     K_type_str = K_type.K_type_str
     df_temp = self.getKTypeDistribution()
@@ -265,71 +265,79 @@ class KineticAnalyzer:
       
       return kinetics_value
 
-  def getTopKTypePerMType(self, M_type):
+  def getTopKTypePerRType(self, R_type):
 
     """
-    Get the most frequent kinetic law type from a certain mass transfer type. 
+    Get the most frequent kinetics type from a certain reaction type. 
 
     Args: 
-        M_type: an object with attributes rct_num and prd_num representing
-            the number of reactants and products.
+        R_type: an object with attributes rct_num and prd_num representing 
+        the number of reactants and products.
 
         rct_num: int-0, 1, 2, 3 (representing > 2).
         
         prd_num: int-0, 1, 2, 3 (representing > 2).
 
     Returns:
-        kinetic_type_list: list of kinetics_type. Sometimes there could be more than one
-        top kinetic law type to make the length of kinetic_type_list larger than one. 
-        
-        kinetic_type: str-kinetic law type. 
+        kinetic_type_list: list of k_type. Sometimes there could be more than one
+        top kinetics type to make the length of kinetic_type_list larger than one. 
+         
+        K_type: an object with an attribute K_type_str representing 
+        the type of kinetic law.
+
+        K_type_str: str-"ZERO" (Zeroth order), "UNDR" 
+        (Uni-directional mass action), "UNMO" (Uni-term with the moderator), "BIDR" 
+        (Bi-directional mass action), "BIMO" (Bi-terms with the moderator), "MM" 
+        (Michaelis-Menten kinetics without an explicit enzyme), "MMCAT" 
+        (Michaelis-Menten kinetics with an explicit enzyme), "HILL" (Hill equations), 
+        "FR" (Kinetic law in the format of fraction other than MM, MMCAT or HILL) and "NA" 
+        (not classified kinetics). 
     """  
-    rct_num = M_type.rct_num
-    prd_num = M_type.prd_num
+    rct_num = R_type.rct_num
+    prd_num = R_type.prd_num
 
     if prd_num in [0,1,2,3] and rct_num in [0,1,2,3]:
-      df_temp = self.getKTypeDistributionPerMType(M_type = M_type)
+      df_temp = self.getKTypeDistributionPerRType(R_type = R_type)
 
       max_value = df_temp['Percentage'].max()
       idx_list = df_temp.index[df_temp['Percentage'] == max_value].tolist()
       kinetics_type_list =[] 
       for i in range(len(idx_list)):
-          kinetics_type_list.append(df_temp.iloc[idx_list[i]]["Classifications"])
+          kinetics_type_list.append(types.K_type(df_temp.iloc[idx_list[i]]["Classifications"]))
       
       return kinetics_type_list
 
     else:
       raise Exception("Not a valid reactant or product number.")
 
-  def getKTypeProbPerMType(self, M_type, K_type):
+  def getKTypeProbPerRType(self, R_type, K_type):
     """
-    Get the probability value of the certain kinetic law type from a certain mass transfer type.
+    Get the probability value of the certain kinetics type from a certain reaction type.
 
     Args:
-        M_type: an object with attributes rct_num and prd_num representing
-            the number of reactants and products.
+        R_type: an object with attributes rct_num and prd_num representing 
+        the number of reactants and products.
 
         rct_num: int-0, 1, 2, 3 (representing > 2).
         
         prd_num: int-0, 1, 2, 3 (representing > 2).
 
-        K_type: an object with attributes K_type_str representing
-            the type of kinetic law.
+        K_type: an object with an attribute K_type_str representing the type of kinetics.
 
         K_type_str: str-"ZERO" (Zeroth order), "UNDR" 
-        (Uni-directional mass action), "UNMO" (Uni-term with moderator), "BIDR" 
-        (Bi-directional mass action), "BIMO" (Bi-terms with moderator), "MM" 
-        (Michaelis-Menten kinetics without explicit enzyme), "MMCAT" 
-        (Michaelis-Menten kinetics with explicit enzyme), "HILL" (Hill equations), 
-        "FR" (Kinetics in the format of fraction other than MM, MMCAT or HILL) and "NA" 
+        (Uni-directional mass action), "UNMO" (Uni-term with the moderator), "BIDR" 
+        (Bi-directional mass action), "BIMO" (Bi-terms with the moderator), "MM" 
+        (Michaelis-Menten kinetics without an explicit enzyme), "MMCAT" 
+        (Michaelis-Menten kinetics with an explicit enzyme), "HILL" (Hill equations), 
+        "FR" (Kinetic law in the format of fraction other than MM, MMCAT or HILL) and "NA" 
         (not classified kinetics). 
 
     Returns:
-        kinetics_value: float-the probability of the certain kinetic law type.
+        kinetics_value: float-the probability of the certain kinetics type.
     """  
     K_type_str = K_type.K_type_str
 
-    df_temp = self.getKTypeDistributionPerMType(M_type = M_type)
+    df_temp = self.getKTypeDistributionPerRType(R_type = R_type)
 
     idx_list = df_temp.index[df_temp['Classifications'] == K_type_str].tolist()
     if len(idx_list) == 0:
@@ -342,19 +350,19 @@ class KineticAnalyzer:
       
       return kinetics_value
 
-  def getTopMType(self):
+  def getTopRType(self):
 
     """
-    Get the most frequent mass transfer type (with the most number of reactions involved in
-    the certain type of mass transfer). 
+    Get the most frequent reaction type (with the largest number of reactions involved in
+    the certain reaction type). 
 
     returns: 
-        rct_prd_num_list: list of M_type info with the most frequent mass transfer 
-        type. Sometimes there could be more than one top kinetic law type to make the length 
+        rct_prd_num_list: list of R_type info with the most frequent reaction 
+        type. Sometimes there could be more than one top kinetics type to make the length 
         of rct_prd_num_list larger than one. 
         
-        M_type: an object with attributes rct_num and prd_num representing
-            the number of reactants and products.
+        R_type: an object with attributes rct_num and prd_num representing 
+        the number of reactants and products.
 
         rct_num: int-0, 1, 2, 3 (representing > 2).
         
@@ -362,7 +370,7 @@ class KineticAnalyzer:
 
     """  
 
-    df_temp = self.getMTypeDistributionPerModel()
+    df_temp = self.getRTypeDistributionPerModel()
 
     max_value = 0
     rct_prd_num_list = []
@@ -385,46 +393,46 @@ class KineticAnalyzer:
         else:
           prd_num = 3 
         
-        rct_prd_num_list.append(types.M_type(rct_num, prd_num))
+        rct_prd_num_list.append(types.R_type(rct_num, prd_num))
 
     return rct_prd_num_list
 
-  def getMTypeProb(self, M_type):
+  def getRTypeProb(self, R_type):
 
     """
     Args:
-        M_type: an object with attributes rct_num and prd_num representing
-            the number of reactants and products.
+        R_type: an object with attributes rct_num and prd_num representing 
+        the number of reactants and products.
 
         rct_num: int-0, 1, 2, 3 (representing > 2).
         
         prd_num: int-0, 1, 2, 3 (representing > 2).
 
     Returns:
-        M_value: float-the probability of the certain mass transfer type.
+        R_value: float-the probability of the certain reaction type.
     """  
-    rct_num = M_type.rct_num
-    prd_num = M_type.prd_num
+    rct_num = R_type.rct_num
+    prd_num = R_type.prd_num
 
     if prd_num in [0,1,2,3] and rct_num in [0,1,2,3]:
-      df_temp = self.getMTypeDistribution()
+      df_temp = self.getRTypeDistribution()
       value = df_temp.iat[prd_num, rct_num]
     else:
         raise Exception("Not a valid reactant or product number.")
 
     return value
 
-  def getNumBiomodelsAnalyzed(self):
+  def getNumSBMLModelsAnalyzed(self):
     """
-    Get the number of biomodels analyzed.
+    Get the number of SBML models analyzed.
     
     Returns:
-        biomodels_num: int-number of biomodels.
+        SBMLModels_num: int-number of SBML models.
     """  
     (_, _, df_mol_stat, _, _, _, _) = self.tuple
-    biomodels_num = len(df_mol_stat)
+    SBMLModels_num = len(df_mol_stat)
     
-    return biomodels_num
+    return SBMLModels_num
   
 
   def getNumRxnsAnalyzed(self):
@@ -443,7 +451,7 @@ class KineticAnalyzer:
   ##Plots 
   def plotKTypeDistribution(self, path = "", fileName = 'KTypeDistribution.pdf'):
     """
-    Plot the kinetic law type distribution and save it as a pdf file.
+    Plot the kinetics type distribution and save it as a pdf file.
 
     Args: 
         path: str-path to the file, with a format like ``D:/path/to/`` (or ``D:\\\path\\\ to\\\``)
@@ -471,14 +479,14 @@ class KineticAnalyzer:
       raise Exception("Please enter a valid pdf file name.")
 
 
-  def plotKTypeDistributionPerMType(self, M_type, path = "", fileName = "KTypeDistributionPerMType.pdf"):
+  def plotKTypeDistributionPerRType(self, R_type, path = "", fileName = "KTypeDistributionPerRType.pdf"):
     """
-    Plot the kinetic law type distribution for a certain mass transfer type and save it as
+    Plot the kinetics type distribution for a certain reaction type and save it as
     a pdf file.
 
-    Args: 
-        M_type: an object with attributes rct_num and prd_num representing
-            the number of reactants and products.
+    Args:  
+        R_type: an object with attributes rct_num and prd_num representing 
+        the number of reactants and products.
 
         rct_num: int-0, 1, 2, 3 (representing > 2).
         
@@ -489,8 +497,8 @@ class KineticAnalyzer:
         fileName: str-file name with which the pdf file save to, ending with ".pdf".
     """  
 
-    rct_num = M_type.rct_num
-    prd_num = M_type.prd_num
+    rct_num = R_type.rct_num
+    prd_num = R_type.prd_num
 
     if str(fileName).lower()[-4:] == ".pdf" and fileName[:-4] != "":
       path_fileName = path + fileName[:-4] + ".pdf"
@@ -508,7 +516,7 @@ class KineticAnalyzer:
 
       if prd_num in [0,1,2,3] and rct_num in [0,1,2,3]:
         i = prd_num*4 + rct_num
-        df_gen_stat_PR_plot[i] = self.getKTypeDistributionPerMType(M_type = M_type)
+        df_gen_stat_PR_plot[i] = self.getKTypeDistributionPerRType(R_type = R_type)
         yerr = df_gen_stat_PR_plot[i][["Percentage standard error", \
           "Percentage per model standard error"]].to_numpy().T
         ax = df_gen_stat_PR_plot[i].plot(kind="bar",x="Classifications", y=["Percentage","Percentage per model"],\
@@ -541,9 +549,9 @@ class KineticAnalyzer:
       raise Exception("Please enter a valid pdf file name.")
 
 
-  def plotKTypeDistributionVsMType(self, path = "", fileName = 'KTypeDistributionVsMType.pdf'):
+  def plotKTypeDistributionVsRType(self, path = "", fileName = 'KTypeDistributionVsRType.pdf'):
     """
-    Plot the kinetic law type distribution vs each mass transfer type and save it as a pdf 
+    Plot the kinetics type distribution vs each reaction type and save it as a pdf 
     file.
   
     Args: 
@@ -571,7 +579,7 @@ class KineticAnalyzer:
       axes = fig.subplots(nrows=4, ncols=4)
       for i in range(16):
         df_gen_stat_PR_plot[i] = \
-          self.getKTypeDistributionPerMType(types.M_type(rct_num=i//4, prd_num=i%4))
+          self.getKTypeDistributionPerRType(types.R_type(rct_num=i//4, prd_num=i%4))
         yerr = df_gen_stat_PR_plot[i][["Percentage standard error", \
           "Percentage per model standard error"]].to_numpy().T
         df_gen_stat_PR_plot[i].plot(ax = axes[i//4,i%4] , kind="bar", 
@@ -601,9 +609,9 @@ class KineticAnalyzer:
       raise Exception("Please enter a valid pdf file name.")
 
 
-  def plotMtypeDistribution(self, path = "", fileName = 'MTypeDistribution.pdf'):
+  def plotRTypeDistribution(self, path = "", fileName = 'RTypeDistribution.pdf'):
     """
-    Plot the distribution of reaction involved for each type of mass transfer and save it 
+    Plot the distribution of reaction involved for reaction type and save it 
     as a pdf file.
   
     Args: 
@@ -614,7 +622,7 @@ class KineticAnalyzer:
     if str(fileName).lower()[-4:] == ".pdf" and fileName[:-4] != "":
       path_fileName = path + fileName[:-4] + ".pdf"
 
-      df_table_PR_plot = self.getMTypeDistribution()
+      df_table_PR_plot = self.getRTypeDistribution()
 
       # Defining figure size for the output plot 
       fig, bx = plt.subplots(figsize = (12, 7))
@@ -635,9 +643,9 @@ class KineticAnalyzer:
       raise Exception("Please enter a valid pdf file name.")
 
 
-  def plotMTypeDistributionPerModel(self, path = "", fileName = 'MTypeDistributionPerModel.pdf'):
+  def plotRTypeDistributionPerModel(self, path = "", fileName = 'RTypeDistributionPerModel.pdf'):
     """
-    Plot the distribution of reactions involved for each type of mass transfer per model and 
+    Plot the distribution of reactions involved for each reaction type per model and 
     save it as a pdf file.
       
     Args: 
@@ -648,7 +656,7 @@ class KineticAnalyzer:
     if str(fileName).lower()[-4:] == ".pdf" and fileName[:-4] != "":
       path_fileName = path + fileName[:-4] + ".pdf"
 
-      df_table_PR_per_model_plot = self.getMTypeDistributionPerModel()
+      df_table_PR_per_model_plot = self.getRTypeDistributionPerModel()
 
       fig, cx = plt.subplots(figsize = (12, 7))
       idx = df_table_PR_per_model_plot.index.tolist()
@@ -670,7 +678,7 @@ class KineticAnalyzer:
   
   def _tableKTypeDistribution(self, path = "", fileName = "KTypeDistribution.xlsx"):
     """
-    Save the kinetic law type distribution to an excel file.
+    Save the kinetics type distribution to an excel file.
 
     Args: 
         path: str-path to the file, with a format like ``D:/path/to/`` (or ``D:\\\path\\\ to\\\``)
@@ -690,13 +698,13 @@ class KineticAnalyzer:
     else:
       raise Exception("Please enter a valid excel file name.")
 
-  def _tableKTypeDistributionPerMType(self, M_type, path = "", fileName = "KTypeDistributionPerMType.xlsx"):
+  def _tableKTypeDistributionPerRType(self, R_type, path = "", fileName = "KTypeDistributionPerRType.xlsx"):
     """
-    Save the kinetic law type distribution for a certain mass transfer type to an excel file.
+    Save the kinetics type distribution for a certain reaction type to an excel file.
 
     Args: 
-        M_type: an object with attributes rct_num and prd_num representing
-            the number of reactants and products.
+        R_Type: an object with attributes rct_num and prd_num representing 
+        the number of reactants and products.
 
         rct_num: int-0, 1, 2, 3 (representing > 2).
         
@@ -709,7 +717,7 @@ class KineticAnalyzer:
     """
 
     if str(fileName).lower()[-5:] == ".xlsx" and fileName[:-5] != "":
-      df_gen_stat_final = self.getKTypeDistributionPerMType(M_type = M_type)
+      df_gen_stat_final = self.getKTypeDistributionPerRType(R_type = R_type)
       # Create a Pandas Excel writer using XlsxWriter as the engine.
       path_fileName = path + fileName[:-5] + ".xlsx"
       writer = pd.ExcelWriter(path_fileName, engine='xlsxwriter')
@@ -719,9 +727,9 @@ class KineticAnalyzer:
     else:
       raise Exception("Please enter a valid excel file name.")
 
-  def _tableMTypeDistribution(self, path = "", fileName = "MTypeDistribution.xlsx"):
+  def _tableRTypeDistribution(self, path = "", fileName = "RTypeDistribution.xlsx"):
     """
-    Save the distribution of reaction involved for each type of mass transfer to an excel file.
+    Save the distribution of reaction involved for each reaction type to an excel file.
 
     Args: 
         path: str-path to the file, with a format like ``D:/path/to/`` (or ``D:\\\path\\\ to\\\``)
@@ -731,7 +739,7 @@ class KineticAnalyzer:
     """  
 
     if str(fileName).lower()[-5:] == ".xlsx" and fileName[:-5] != "":
-      df_gen_stat_final = self.getMTypeDistribution()
+      df_gen_stat_final = self.getRTypeDistribution()
       # Create a Pandas Excel writer using XlsxWriter as the engine.
       path_fileName = path + fileName[:-5] + ".xlsx"
       writer = pd.ExcelWriter(path_fileName, engine='xlsxwriter')
@@ -741,9 +749,9 @@ class KineticAnalyzer:
     else:
       raise Exception("Please enter a valid excel file name.") 
 
-  def _tableMTypeDistributionPerModel(self, path = "", fileName = "MTypeDistributionPerModel.xlsx"):
+  def _tableRTypeDistributionPerModel(self, path = "", fileName = "RTypeDistributionPerModel.xlsx"):
     """
-    Save the distribution of reaction involved for each type of mass transfer per model to an 
+    Save the distribution of reaction involved for each reaction type per model to an 
     excel file.
 
     Args: 
@@ -754,7 +762,7 @@ class KineticAnalyzer:
     """  
 
     if str(fileName).lower()[-5:] == ".xlsx" and fileName[:-5] != "":
-      df_gen_stat_final = self.getMTypeDistributionPerModel()
+      df_gen_stat_final = self.getRTypeDistributionPerModel()
       # Create a Pandas Excel writer using XlsxWriter as the engine.
       path_fileName = path + fileName[:-5] + ".xlsx"
       writer = pd.ExcelWriter(path_fileName, engine='xlsxwriter')
@@ -766,7 +774,7 @@ class KineticAnalyzer:
 
   def _printBriefStatOfKTypeDistribution(self):
     """
-    Print the brief statistics for the kinetic law type distribution.
+    Print the brief statistics for the kinetics type distribution.
     """  
     (df_classification, df_gen_stat, _, _, biomodel_non_count, _, _) = self.tuple
     rxn_num = len(df_classification)
@@ -778,7 +786,7 @@ class KineticAnalyzer:
         print(df_gen_stat.iloc[i][CLASSIFICATIONS] + ":" + str(df_gen_stat.iloc[i][PERCENTAGE]))
     else:
       print("There are no reactions.")
-    print("number of biomodels with some reactions not classified:", biomodel_non_count)
+    print("number of SBML models with some reactions not classified:", biomodel_non_count)
 
   def _printKTypePerRxn(self):
     """
@@ -836,35 +844,35 @@ if __name__ == '__main__':
 
   # #Query Distributions
   # print(analyzer.getKTypeDistribution()) 
-  # print(analyzer.getKTypeDistributionPerMType(M_type = types.M_type(1,1)))
-  # print(analyzer.getMTypeDistribution())
-  # print(analyzer.getMTypeDistributionPerModel())
+  # print(analyzer.getKTypeDistributionPerRType(R_type = types.R_type(1,1)))
+  # print(analyzer.getRTypeDistribution())
+  # print(analyzer.getRTypeDistributionPerModel())
 
   
   #Query Elements
   # print(analyzer.getTopKType()[0].K_type_str)
   # print(analyzer.getKTypeProb(K_type = types.K_type("NA")))
-  # print(analyzer.getTopKTypePerMType(M_type = types.M_type(1,1)))
-  # print(analyzer.getKTypeProbPerMType(M_type = types.M_type(1,1), K_type=types.K_type("NA")))
-  # print(analyzer.getTopMType()[0].rct_num)
-  # print(analyzer.getMTypeProb(M_type = types.M_type(1,1)))
-  # print(analyzer.getNumBiomodelsAnalyzed())
+  # print(analyzer.getTopKTypePerRType(R_type = types.R_type(1,1))[0].K_type_str)
+  # print(analyzer.getKTypeProbPerRType(R_type = types.R_type(1,1), K_type=types.K_type("NA")))
+  # print(analyzer.getTopRType()[0].rct_num)
+  # print(analyzer.getRTypeProb(R_type = types.R_type(1,1)))
+  # print(analyzer.getNumSBMLModelsAnalyzed())
   # print(analyzer.getNumRxnsAnalyzed())
 
 
   # #Plots #tests are not necessary
   # analyzer.plotKTypeDistribution(path = 'D:/summer-2020/Jo/')
-  # analyzer.plotKTypeDistributionPerMType(M_type = types.M_type(1,1))
-  # analyzer.plotKTypeDistributionVsMType()
-  # analyzer.plotMtypeDistribution()
-  # analyzer.plotMTypeDistributionPerModel()
+  analyzer.plotKTypeDistributionPerRType(R_type = types.R_type(1,1))
+  # analyzer.plotKTypeDistributionVsRType()
+  # analyzer.plotRTypeDistribution()
+  # analyzer.plotRTypeDistributionPerModel()
 
   # #Tables
   # analyzer._tableKTypeDistribution(path = 'D:/summer-2020/Jo/', fileName = "Kinetics.xlsx")
   # analyzer._tableKTypeDistribution()
-  # analyzer._tableKTypeDistributionPerMType(M_type = types.M_type(1,1))
-  # analyzer._tableMTypeDistribution()
-  # analyzer._tableMTypeDistributionPerModel()
+  # analyzer._tableKTypeDistributionPerRType(R_type = types.R_type(1,1))
+  # analyzer._tableRTypeDistribution()
+  # analyzer._tableRTypeDistributionPerModel()
 
 
   # analyzer._printBriefStatOfKTypeDistribution()
